import Loading from './Loading.vue';
import Viz from "@aduh95/viz.js";
import getWorker from "@aduh95/viz.js/worker";

const worker = getWorker();
const viz = new Viz({ worker });

const Graphviz = {
  name: 'Graphviz',
  props: {
    id: {
      type: String,
      required: true
    },
    graph: {
      type: String,
      required: true
    },
  },
  data () {
    return {
      svg: undefined
    }
  },
  render (h) {
    if (this.svg === undefined) {
      return h('Loading')
    }

    return h('div', {
      class: 'graphviz',
      domProps: {
        innerHTML: this.svg,
        style: 'width: 100%'
      }
    })
  },
  mounted () {
    window.global ||= {};

    const content = this.graph || this.$el.querySelector(".graph-data").textContent;

    viz
      .renderString(content)
      .then(svgString => {
        this.svg = svgString
      })
  },
  components: {
    Loading
  }
}

export default ({ Vue }) => {
  Vue.component('Graphviz', Graphviz)
}
